## 1.15.1.6 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.15.1.5 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 1.15.1.4 (2023-01-18)

Replace `Any` with `Incomplete` in many places (#9558)

## 1.15.1.3 (2022-11-13)

`cffi`: run stubtest on Windows (#9178)

## 1.15.1.2 (2022-11-09)

All `__nonzero__` are methods that return `bool` (#9139)

## 1.15.1.1 (2022-11-09)

Annotate known magic-method return types (#9131)

## 1.15.1 (2022-09-27)

Bump mypy to 0.981 (#8796)

## 1.15.0 (2022-09-15)

Add type stubs for cffi (#8736)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

